/* global Drupal */

// Ensure $ is available: Foundation and select2 need to bind to it
import $ from 'jquery'
import select2 from 'select2'

import { Foundation, SmoothScroll, Toggler } from 'foundation-sites/js/foundation'
import { SelectTwo, AdaptiveSticky, StickyButton } from '@moreonion/foundation-base'

// Add the select2 to jQuery
// Needed for SelectTwo plugin
select2($)

// Add Foundation to jQuery
Foundation.addToJquery($)

// Configure Foundation
Foundation.plugin(SmoothScroll, 'SmoothScroll')
Foundation.plugin(Toggler, 'Toggler')
Foundation.plugin(SelectTwo, 'SelectTwo')
Foundation.plugin(AdaptiveSticky, 'AdaptiveSticky')
Foundation.plugin(StickyButton, 'StickyButton')

// Let foundation initialize the initial markup
// This needs to be done for dynamically loaded markup too (e.g. AJAX markup)
export function initFoundation () {
  if (typeof Drupal !== 'undefined') {
    Drupal.behaviors.foundist_initialize = {}
    Drupal.behaviors.foundist_initialize.attach = (context, settings) => {
      $(context).foundation()
    }
  } else {
    $(window.document).foundation()
  }
}

// Activate AdaptiveSticky on forms in the sidebar.
export function stickyForm () {
  const $form = $('#sidebar form')
  if (!$form.length) {
    return
  }
  const $sidebar = $('#sidebar')
  // Add a wrapper around the #sidebar content to make all of it sticky.
  $sidebar.children().wrapAll('<div class="sticky" />')
  // Let the actual form inside #form stick to the window top.
  return new Foundation.AdaptiveSticky($sidebar.children('.sticky'), {
    target: '#form-outer form',
    offset: $('#form-outer').css('padding-top'),
    mediaQuery: 'large'
  })
}

// Activate StickyButton on CTA markup snippet.
export function stickyButton () {
  let $cta = $('.sticky-cta')
  if (!$cta.length) {
    return
  }
  // Put button(s) in right position.
  // Depending on the layout, the button should be on the bottom of the page,
  // the sidebar or the main wrapper for large screen sizes.
  const target = $cta.find('a').attr('href')
  if ($('#sidebar, #main .inner-wrapper').length) {
    const $clone = $cta.clone().appendTo($('#sidebar, #main .inner-wrapper')).addClass('bottom show-for-large')
    $cta.appendTo('#page').addClass('bottom hide-for-large')
    $cta = $cta.add($clone)
  } else {
    $cta.appendTo('#page').addClass('bottom')
  }
  // Add SmoothScroll
  const scroll = new SmoothScroll($cta.find('a'))
  // Initialize plugin
  return $cta.map((i, el) => {
    return new Foundation.StickyButton($(el), {
      blocker: target,
      topOverlap: 0.3
    })
  })
}

// Activate cookiebar on CTA markup snippet.
export function cookiebar () {
  const $cookiebar = $('#cookiebar')
  if (!$cookiebar.length) {
    return
  }
  // Put cookiebar in right position.
  $cookiebar.detach().appendTo('body')
  $cookiebar.css('bottom', -1 * $cookiebar.outerHeight())

  // Prepare tracking allowed event
  const event = document.createEvent('Event')
  event.initEvent('tracking-allowed', false, false)

  function show() {
    $cookiebar.show()
    $cookiebar.css('bottom', '0').css('opacity', 1)
  }

  function hide() {
    $cookiebar.css('bottom', -1 * $cookiebar.outerHeight()).css('opacity', 0)
    if ($cookiebar.css('transition-duration')) {
      $cookiebar.on('transitionend.zf.cookiebar', () => {
        $cookiebar.hide().off('transitionend.zf.cookiebar')
      })
    } else {
      $cookiebar.hide()
    }
  }

  // If cookies are already allowed dispatch the tracking-allowed event.
  // Otherwise show the cookiebar and dispatch the event once it's approved.
  //
  // NB: There is currently no option to save a "no" to cookies. The cookiebar will show every
  // time until you accept it...
  if (document.cookie.indexOf('cookieaccepted') >= 0) {
    document.dispatchEvent(event)
  } else {
    $('.accept-cookies').click(function () {
      document.cookie = 'cookieaccepted=1; max-age=31536000; path=/'
      document.dispatchEvent(event)
      hide()
    })
    $('.block-cookies').click(function () {
      hide()
    })
    show()
  }
}
